@@ -5,6 +5,8 @@ class Operator(_Enum):
     # all valid filter operators for querying file events
     IS = "IS"
     IS_NOT = "IS_NOT"
+    IS_ANY = "IS_ANY"
+    IS_NONE = "IS_NONE"
     EXISTS = "EXISTS"
     DOES_NOT_EXIST = "DOES_NOT_EXIST"
     GREATER_THAN = "GREATER_THAN"
@@ -34,6 +36,7 @@ class EventSearchTerm(_Enum):
     DESTINATION_PRINTED_FILES_BACKUP_PATH = "destination.printedFilesBackupPath"
     DESTINATION_PRINTER_NAME = "destination.printerName"
     DESTINATION_PRIVATE_IP = "destination.privateIp"
+    DESTINATION_REMOTE_HOSTNAME = "destination.remoteHostname"
     DESTINATION_REMOVABLE_MEDIA_BUS_TYPE = "destination.removableMedia.busType"
     DESTINATION_REMOVABLE_MEDIA_CAPACITY = "destination.removableMedia.capacity"
     DESTINATION_REMOVABLE_MEDIA_MEDIA_NAME = "destination.removableMedia.mediaName"
@@ -65,9 +68,31 @@ class EventSearchTerm(_Enum):
     EVENT_RELATED_EVENTS_TABS_URL_ERROR = "event.relatedEvents.tabs.urlError"
     EVENT_RELATED_EVENTS_USER_EMAIL = "event.relatedEvents.userEmail"
     EVENT_SHARE_TYPE = "event.shareType"
+    EVENT_DETECTOR_DISPLAY_NAME = "event.detectorDisplayName"
+    EVENT_VECTOR = "event.vector"
+    FILE_ACQUIRED_FROM_GIT_REPOSITORY_EMAIL = "file.acquiredFrom.git.repositoryEmail"
+    FILE_ACQUIRED_FROM_GIT_REPOSITORY_URI = "file.acquiredFrom.git.repositoryUri"
+    FILE_ACQUIRED_FROM_GIT_REPOSITORY_USER = "file.acquiredFrom.git.repositoryUser"
+    FILE_ACQUIRED_FROM_TABS_URL_ERROR = "file.acquiredFrom.tabs.urlError"
+    FILE_ACQUIRED_FROM_SOURCE_DOMAINS = "file.acquiredFrom.sourceDomains"
+    FILE_ACQUIRED_FROM_USER_EMAIL = "file.acquiredFrom.userEmail"
+    FILE_ACQUIRED_FROM_SOURCE_USER_EMAIL = "file.acquiredFrom.sourceUser.email"
+    FILE_ACQUIRED_FROM_TABS_URL = "file.acquiredFrom.tabs.url"
+    FILE_ACQUIRED_FROM_EVENT_ID = "file.acquiredFrom.eventId"
+    FILE_ACQUIRED_FROM_FILE_NAME = "file.acquiredFrom.fileName"
+    FILE_ACQUIRED_FROM_SOURCE_CATEGORY = "file.acquiredFrom.sourceCategory"
+    FILE_ACQUIRED_FROM_SOURCE_ACCOUNT_NAME = "file.acquiredFrom.sourceAccountName"
+    FILE_ACQUIRED_FROM_SOURCE_NAME = "file.acquiredFrom.sourceName"
+    FILE_ACQUIRED_FROM_AGENT_TIMESTAMP = "file.acquiredFrom.agentTimestamp"
+    FILE_ACQUIRED_FROM_EVENT_ACTION = "file.acquiredFrom.eventAction"
+    FILE_ACQUIRED_FROM_TABS_TITLE_ERROR = "file.acquiredFrom.tabs.titleError"
+    FILE_ACQUIRED_FROM_TABS_TITLE = "file.acquiredFrom.tabs.title"
+    FILE_ACQUIRED_FROM_SOURCE_ACCOUNT_TYPE = "file.acquiredFrom.sourceAccountType"
+    FILE_ACQUIRED_FROM_MD5 = "file.acquiredFrom.md5"
     FILE_CATEGORY = "file.category"
     FILE_CATEGORY_BY_BYTES = "file.categoryByBytes"
     FILE_CATEGORY_BY_EXTENSION = "file.categoryByExtension"
+    FILE_CHANGE_TYPE = "file.changeType"
     FILE_CLASSIFICATIONS_VALUE = "file.classifications.value"
     FILE_CLASSIFICATIONS_VENDOR = "file.classifications.vendor"
     FILE_CLOUD_DRIVE_ID = "file.cloudDriveId"
@@ -83,9 +108,17 @@ class EventSearchTerm(_Enum):
     FILE_MIME_TYPE_BY_EXTENSION = "file.mimeTypeByExtension"
     FILE_MODIFIED = "file.modified"
     FILE_NAME = "file.name"
+    FILE_ORIGINAL_NAME = "file.originalName"
+    FILE_ORIGINAL_DIRECTORY = "file.originalDirectory"
     FILE_OWNER = "file.owner"
     FILE_SIZE_IN_BYTES = "file.sizeInBytes"
     FILE_URL = "file.url"
+    GIT_REPOSITORY_URI = "git.repositoryUri"
+    GIT_LAST_COMMIT_HASH = "git.lastCommitHash"
+    GIT_EVENT_ID = "git.eventId"
+    GIT_REPOSITORY_ENDPOINT_PATH = "git.repositoryEndpointPath"
+    GIT_REPOSITORY_USER = "git.repositoryUser"
+    GIT_REPOSITORY_EMAIL = "git.repositoryEmail"
     PROCESS_EXECUTABLE = "process.executable"
     PROCESS_OWNER = "process.owner"
     REPORT_COUNT = "report.count"
@@ -96,10 +129,18 @@ class EventSearchTerm(_Enum):
     REPORT_TYPE = "report.type"
     RISK_INDICATORS_NAME = "risk.indicators.name"
     RISK_INDICATORS_WEIGHT = "risk.indicators.weight"
+    RISK_INDICATORS_ID = "risk.indicators.id"
     RISK_SCORE = "risk.score"
     RISK_SEVERITY = "risk.severity"
     RISK_TRUST_REASON = "risk.trustReason"
     RISK_TRUSTED = "risk.trusted"
+    RISK_UNTRUSTED_VALUES_GIT_REPOSITORY_URIS = "risk.untrustedValues.gitRepositoryUris"
+    RISK_UNTRUSTED_VALUES_URL_PATHS = "risk.untrustedValues.urlPaths"
+    RISK_UNTRUSTED_VALUES_DOMAINS = "risk.untrustedValues.domains"
+    RISK_UNTRUSTED_VALUES_SLACK_WORKSPACES = "risk.untrustedValues.slackWorkspaces"
+    RISK_UNTRUSTED_VALUES_ACCOUNT_NAMES = "risk.untrustedValues.accountNames"
+    SOURCE_ACCOUNT_TYPE = "source.accountType"
+    SOURCE_ACCOUNT_NAME = "source.accountName"
     SOURCE_CATEGORY = "source.category"
     SOURCE_DOMAIN = "source.domain"
     SOURCE_DOMAINS = "source.domains"
@@ -121,6 +162,7 @@ class EventSearchTerm(_Enum):
     SOURCE_TABS_TITLE_ERROR = "source.tabs.titleError"
     SOURCE_TABS_URL = "source.tabs.url"
     SOURCE_TABS_URL_ERROR = "source.tabs.urlError"
+    SOURCE_USER_EMAIL = "source.user.email"
     USER_DEVICE_UID = "user.deviceUid"
     USER_EMAIL = "user.email"
     USER_ID = "user.id"
