@@ -1,6 +1,7 @@
 from datetime import datetime
 from typing import List
 from typing import Optional
+from typing import Union
 
 from pydantic import Field
 
@@ -9,6 +10,81 @@ from _incydr_sdk.core.models import ResponseModel
 from _incydr_sdk.enums.file_events import ReportType
 
 
+class UserJustification(Model):
+    reason: Optional[str] = Field(
+        None, title="User-select justification for temporarily allowing this action."
+    )
+    text: Optional[str] = Field(
+        None,
+        title="User-select justification for temporarily allowing this action. Only applies when reason is 'Other'.",
+    )
+
+
+class ResponseControls(Model):
+    preventative_control: Optional[str] = Field(
+        None,
+        alias="preventativeControl",
+        example="BLOCKED",
+        title="The preventative action applied to this event",
+    )
+    user_justification: Optional[UserJustification] = Field(
+        None, alias="userJustification"
+    )
+
+
+class AcquiredFromGit(Model):
+    repository_email: Optional[str] = Field(
+        None,
+        alias="repositoryEmail",
+        title="The email address specified by the user who performed the Git event. This is a user-defined value and may differ from the credentials used to sign in to Git.",
+    )
+    repository_uri: Optional[str] = Field(
+        None,
+        alias="repositoryUri",
+        title="Uniform Resource Identifier (URI) for the Git repository.",
+    )
+    repository_user: Optional[str] = Field(
+        None,
+        alias="repositoryUser",
+        title="The username specified by the user who performed the Git event. This is a user-defined value and may differ from the credentials used to sign in to Git.",
+    )
+
+
+class AcquiredFromSourceUser(Model):
+    email: Optional[List[str]] = Field(
+        None,
+        example=["first.last@example.com", "first_last_example_com"],
+        title="For endpoint events where a file in cloud storage is synced to a device, the email address of the user logged in to the cloud storage provider.",
+    )
+
+
+class UntrustedValues(Model):
+    account_names: List[str] = Field(
+        ...,
+        alias="accountNames",
+        title="Account names that do not match an entry in your list of Trusted activity. Values are obtained from the account name metadata for the event. Only applies to event types that are evaluated for trust.",
+    )
+    domains: List[str] = Field(
+        ...,
+        title="Domains that do not match an entry in your list of Trusted activity. Values are obtained from the domain section of related metadata for the event. Only applies to event types that are evaluated for trust.",
+    )
+    git_repository_uris: List[str] = Field(
+        ...,
+        alias="gitRepositoryUris",
+        title="Git URIs that do not match an entry in your list of Trusted activity. Values are obtained from the Git URI metadata for the event. Only applies to event types that are evaluated for trust.",
+    )
+    slack_workspaces: List[str] = Field(
+        ...,
+        alias="slackWorkspaces",
+        title="Slack workspaces that do not match an entry in your list of Trusted activity. Values are obtained from the Slack metadata for the event. Only applies to event types that are evaluated for trust.",
+    )
+    url_paths: List[str] = Field(
+        ...,
+        alias="urlPaths",
+        title="URL paths that do not match an entry in your list of Trusted activity. Values are obtained from the URL metadata for the event. Only applies to event types that are evaluated for trust.",
+    )
+
+
 class DestinationEmail(Model):
     recipients: Optional[List[str]] = Field(
         description="The email addresses of those who received the email. Includes the To, Cc, and Bcc recipients.",
@@ -55,15 +131,33 @@ class Hash(Model):
     )
 
 
+class Extension(Model):
+    browser: Optional[str] = Field(
+        None, title="The web browser in which the event occurred."
+    )
+    version: Optional[str] = Field(
+        None,
+        title="The version of the Code42 Incydr extension installed when the event occurred.",
+    )
+    logged_in_user: Optional[str] = Field(
+        None,
+        alias="loggedInUser",
+        title="The user signed in to the active tab where the event occurred. For example, the user signed in to Gmail. This may differ from the user account signed in to the browser itself.",
+    )
+
+
 class Process(Model):
     executable: Optional[str] = Field(
+        None,
         description="The name of the process that accessed the file, as reported by the device’s operating system. Depending on your Code42 product plan, this value may be null for some event types.",
         example="bash",
     )
     owner: Optional[str] = Field(
+        None,
         description="The username of the process owner, as reported by the device’s operating system. Depending on your Code42 product plan, this value may be null for some event types.",
         example="root",
     )
+    extension: Optional[Extension]
 
 
 class RemovableMedia(Model):
@@ -133,7 +227,7 @@ class Report(Model):
         description="The display name of the report.",
         example="Top Accounts Report",
     )
-    type: Optional[ReportType] = Field(
+    type: Optional[Union[ReportType, str]] = Field(
         description='Indicates if the report is "REPORT_TYPE_AD_HOC" or "REPORT_TYPE_SAVED".',
         example="REPORT_TYPE_SAVED",
     )
@@ -144,6 +238,9 @@ class RiskIndicator(Model):
         description="Name of the risk indicator.",
         example="Browser upload",
     )
+    id: Optional[str] = Field(
+        None, title="The unique identifier for the risk indicator."
+    )
     weight: Optional[int] = Field(
         description="Configured weight of the risk indicator at the time this event was seen.",
         example=5,
@@ -208,63 +305,74 @@ class User(Model):
 
 
 class AcquiredFrom(Model):
-    agent_timestamp: Optional[datetime] = Field(
-        None,
-        alias="agentTimestamp",
-        description="Date and time that the Code42 service on the device detected an event; based on the device’s system clock and reported in Coordinated Universal Time (UTC).",
-        example="2020-10-27T15:16:05.369203Z",
-    )
-    event_action: Optional[str] = Field(
-        None,
-        alias="eventAction",
-        description="The type of file event observed. For example: file-modified, application-read, removable-media-created.",
-        example="file-downloaded",
-    )
     event_id: Optional[str] = Field(
         None,
         alias="eventId",
-        description="The unique identifier for the event.",
         example="0_147e9445-2f30-4a91-8b2a-9455332e880a_973435567569502913_986467523038446097_163",
+        title="The unique identifier for the event.",
     )
-    file_name: Optional[str] = Field(
-        None,
-        alias="fileName",
-        description="The name of the file, including the file extension.",
-        example="example.txt",
+    tabs: Optional[List[Tab]] = Field(
+        None, title="Metadata about the browser tab source."
     )
-    md5: Optional[str] = Field(
+    source_account_name: Optional[str] = Field(
         None,
-        description="The MD5 hash of the file contents.",
-        example="6123bbce7f3937667a368bbb9f3d79ce",
+        alias="sourceAccountName",
+        title="For cloud sync apps installed on user devices, the name of the cloud account where the event was observed. This can help identify if the activity occurred in a business or personal account.",
+    )
+    source_account_type: Optional[str] = Field(
+        None,
+        alias="sourceAccountType",
+        title="For cloud sync apps installed on user devices, the type of account where the event was observed. For example, 'BUSINESS' or 'PERSONAL'.",
     )
     source_category: Optional[str] = Field(
         None,
         alias="sourceCategory",
-        description="General category of where the file originated. For example: Cloud Storage, Email, Social Media.",
         example="Social Media",
-    )
-    source_domains: Optional[List[str]] = Field(
-        None,
-        alias="sourceDomains",
-        description="The domain section of the URLs reported in file.acquiredFrom.tabs.url.",
-        example="example.com",
+        title="General category of where the file originated. For example: Cloud Storage, Email, Social Media.",
     )
     source_name: Optional[str] = Field(
         None,
         alias="sourceName",
-        description="The name reported by the device's operating system.  This may be different than the device name in the Code42 console.",
         example="Mari's MacBook",
+        title="The name reported by the device's operating system.  This may be different than the device name in the Code42 console.",
     )
-    tabs: Optional[List[Tab]] = Field(
+    source_user: Optional[AcquiredFromSourceUser] = Field(None, alias="sourceUser")
+    agent_timestamp: Optional[datetime] = Field(
         None,
-        description="Metadata about the browser tab source.",
+        alias="agentTimestamp",
+        example="2020-10-27T15:16:05.369203Z",
+        title="Date and time that the Code42 service on the device detected an event; based on the device’s system clock and reported in Coordinated Universal Time (UTC).",
     )
     user_email: Optional[str] = Field(
         None,
         alias="userEmail",
-        description="The Code42 username used to sign in to the Code42 app on the device (for endpoint events) or the cloud service username of the person who caused the event (for cloud events).",
         example="cody@example.com",
+        title="The Code42 username used to sign in to the Code42 app on the device (for endpoint events) or the cloud service username of the person who caused the event (for cloud events).",
     )
+    event_action: Optional[str] = Field(
+        None,
+        alias="eventAction",
+        example="file-downloaded",
+        title="The type of file event observed. For example: file-modified, application-read, removable-media-created.",
+    )
+    source_domains: Optional[List[str]] = Field(
+        None,
+        alias="sourceDomains",
+        example="example.com",
+        title="The domain section of the URLs reported in file.acquiredFrom.tabs.url.",
+    )
+    file_name: Optional[str] = Field(
+        None,
+        alias="fileName",
+        example="example.txt",
+        title="The name of the file, including the file extension.",
+    )
+    md5: Optional[str] = Field(
+        None,
+        example="6123bbce7f3937667a368bbb9f3d79ce",
+        title="The MD5 hash of the file contents.",
+    )
+    git: Optional[AcquiredFromGit] = None
 
 
 class Destination(Model):
@@ -326,6 +434,11 @@ class Destination(Model):
     user: Optional[DestinationUser] = Field(
         description="Metadata about the destination user."
     )
+    remote_hostname: Optional[str] = Field(
+        None,
+        alias="remoteHostname",
+        title="For events where a file transfer tool was used, the destination hostname.",
+    )
 
 
 class File(Model):
@@ -366,6 +479,12 @@ class File(Model):
         description="The file location on the user's device; a forward or backslash must be included at the end of the filepath. Possibly null if the file event occurred on a cloud provider.",
         example="/Users/alix/Documents/",
     )
+    original_directory: Optional[str] = Field(
+        None,
+        alias="originalDirectory",
+        example="/Users/alix/Documents/",
+        title="The original file location on the user’s device or cloud service location; a forward or backslash must be included at the end of the filepath. Possibly null if the file event occurred on a cloud provider.",
+    )
     directory_id: Optional[List[str]] = Field(
         alias="directoryId",
         description="Unique identifiers of the parent drives that contain the file; searching on directoryId will return events for all of the files contained in the parent drive.",
@@ -376,6 +495,11 @@ class File(Model):
         description="Unique identifier reported by the cloud provider for the file associated with the event.",
         example="PUL5zWLRrdudiJZ1OCWw",
     )
+    mime_type: Optional[str] = Field(
+        None,
+        alias="mimeType",
+        title="The MIME type of the file. For endpoint events, if the mimeTypeByBytes differs from mimeTypeByExtension, this indicates the most likely MIME type for the file. For activity observed by a web browser, this is the only MIME type reported.",
+    )
     mime_type_by_bytes: Optional[str] = Field(
         alias="mimeTypeByBytes",
         description="The MIME type of the file based on its contents.",
@@ -394,6 +518,12 @@ class File(Model):
         description="The name of the file, including the file extension.",
         example="ReadMe.md",
     )
+    original_name: Optional[str] = Field(
+        None,
+        alias="originalName",
+        example="ReadMe.md",
+        title="The original name of the file, including the file extension.",
+    )
     owner: Optional[str] = Field(
         description="The name of the user who owns the file as reported by the device's file system.",
         example="ari.example",
@@ -405,6 +535,21 @@ class File(Model):
         description="URL reported by the cloud provider at the time the event occurred.",
         example="https://example.com",
     )
+    archive_id: Optional[str] = Field(
+        None,
+        alias="archiveId",
+        title="Unique identifier for files identified as an archive, such as .zip files.",
+    )
+    parent_archive_id: Optional[str] = Field(
+        None,
+        alias="parentArchiveId",
+        title="For files contained within an archive (such as a .zip file), the unique identifier for that archive; searching on parentArchiveID returns events for all files contained within that archive",
+    )
+    password_protected: Optional[bool] = Field(
+        None,
+        alias="passwordProtected",
+        title="Indicates if this file is password protected.",
+    )
 
 
 class Risk(Model):
@@ -428,6 +573,7 @@ class Risk(Model):
         description="Indicates whether or not the file activity is trusted based on your Data Preferences settings.",
         example=True,
     )
+    untrusted_values: UntrustedValues = Field(..., alias="untrustedValues")
 
 
 class Source(Model):
@@ -471,6 +617,11 @@ class Source(Model):
         description="The IP address of the user's device on your internal network, including Network interfaces, Virtual Network Interface controllers (NICs), and Loopback/non-routable addresses.",
         example=["127.0.0.1", "127.0.0.2"],
     )
+    remote_hostname: Optional[str] = Field(
+        None,
+        alias="remoteHostname",
+        title="For events where a file transfer tool was used, the source hostname.",
+    )
     removable_media: Optional[RemovableMedia] = Field(
         alias="removableMedia",
         description="Metadata about the removable media source.",
@@ -539,6 +690,11 @@ class Event(Model):
         description="The data source that captured the file event. For example: GoogleDrive, Office365, Salesforce.",
         example="Endpoint",
     )
+    detector_display_name: Optional[str] = Field(
+        None,
+        alias="detectorDisplayName",
+        title="Indicates the name you provided when the cloud data connection was initially configured in the Code42 console.",
+    )
     related_events: Optional[List[RelatedEvent]] = Field(
         alias="relatedEvents",
         description="List of other events associated with this file. This can help determine the origin of the file.",
@@ -548,22 +704,56 @@ class Event(Model):
         description="Sharing types added by this event.",
         example=["SharedViaLink"],
     )
-    vector: Optional[str]
+    vector: Optional[str] = Field(
+        None,
+        example="GIT_PUSH",
+        title="The method of file movement. For example: UPLOADED, DOWNLOADED, EMAILED.",
+    )
+    xfc_event_id: Optional[str] = Field(
+        None,
+        alias="xfcEventId",
+        description="The identifier for the exfiltrated file collection data associated with this event.",
+    )
 
 
 class Git(Model):
-    event_id: Optional[str] = Field(None, alias="eventId")
-    last_commit_hash: Optional[str] = Field(None, alias="lastCommitHash")
-    repository_email: Optional[str] = Field(None, alias="repositoryEmail")
+    event_id: Optional[str] = Field(
+        None,
+        alias="eventId",
+        title="A global unique identifier (GUID) generated by Incydr for this Git event. All files associated with this event have the same Git event ID. A single Git event can be associated with multiple file events.",
+    )
+    last_commit_hash: Optional[str] = Field(
+        None,
+        alias="lastCommitHash",
+        title="Hash value from the most recent commit in this Git event.",
+    )
+    repository_email: Optional[str] = Field(
+        None,
+        alias="repositoryEmail",
+        title="The email address specified by the user who performed the Git event. This is a user-defined value and may differ from the credentials used to sign in to Git.",
+    )
     repository_endpoint_path: Optional[str] = Field(
-        None, alias="repositoryEndpointPath"
+        None,
+        alias="repositoryEndpointPath",
+        title="File path of the local Git repository on the user's endpoint.",
+    )
+    repository_uri: Optional[str] = Field(
+        None,
+        alias="repositoryUri",
+        title="Uniform Resource Identifier (URI) for the Git repository.",
+    )
+    repository_user: Optional[str] = Field(
+        None,
+        alias="repositoryUser",
+        title="The username specified by the user who performed the Git event. This is a user-defined value and may differ from the credentials used to sign in to Git.",
     )
-    repository_uri: Optional[str] = Field(None, alias="repositoryUri")
-    repository_user: Optional[str] = Field(None, alias="repositoryUser")
 
 
 class FileEventV2(ResponseModel):
     """
+    New fields are often being made available on the event response and this model definition may not contain the most recent additions.
+    See the response definition for the [File Event Search API](https://developer.code42.com/api/#tag/File-Events/operation/searchEvents) for the most up to date information on what data is available.
+
     **Fields**:
 
     * **timestamp**: - The date and time that the Code42 service on the device detected the event.  This timestamp is based on the device’s system clock and reported in Coordinated Universal Time (UTC).
@@ -598,6 +788,10 @@ class FileEventV2(ResponseModel):
     report: Optional[Report] = Field(
         description="Metadata for reports from 3rd party sources, such Salesforce downloads.",
     )
+    response_controls: Optional[ResponseControls] = Field(
+        alias="responseControls",
+        description="Metadata about preventative actions applied to file activity. Only applies to events for users on a preventative watchlist.",
+    )
     risk: Optional[Risk] = Field(
         description="Risk factor metadata.",
     )
