@@ -5,29 +5,31 @@ from typing import Union
 
 from _incydr_sdk.enums.watchlists import WatchlistType
 from _incydr_sdk.exceptions import WatchlistNotFoundError
+from _incydr_sdk.watchlists.clientv1 import WatchlistsV1
 from _incydr_sdk.watchlists.models.requests import CreateWatchlistRequest
-from _incydr_sdk.watchlists.models.requests import ListWatchlistsRequest
-from _incydr_sdk.watchlists.models.requests import UpdateExcludedUsersRequest
+from _incydr_sdk.watchlists.models.requests import ListWatchlistsRequestV2
+from _incydr_sdk.watchlists.models.requests import UpdateExcludedActorsRequest
+from _incydr_sdk.watchlists.models.requests import UpdateIncludedActorsRequest
 from _incydr_sdk.watchlists.models.requests import UpdateIncludedDepartmentsRequest
 from _incydr_sdk.watchlists.models.requests import UpdateIncludedDirectoryGroupsRequest
-from _incydr_sdk.watchlists.models.requests import UpdateIncludedUsersRequest
 from _incydr_sdk.watchlists.models.requests import UpdateWatchlistRequest
-from _incydr_sdk.watchlists.models.responses import ExcludedUsersList
+from _incydr_sdk.watchlists.models.responses import ExcludedActorsList
+from _incydr_sdk.watchlists.models.responses import IncludedActorsList
 from _incydr_sdk.watchlists.models.responses import IncludedDepartment
 from _incydr_sdk.watchlists.models.responses import IncludedDepartmentsList
 from _incydr_sdk.watchlists.models.responses import IncludedDirectoryGroup
 from _incydr_sdk.watchlists.models.responses import IncludedDirectoryGroupsList
-from _incydr_sdk.watchlists.models.responses import IncludedUsersList
 from _incydr_sdk.watchlists.models.responses import Watchlist
-from _incydr_sdk.watchlists.models.responses import WatchlistMembersList
+from _incydr_sdk.watchlists.models.responses import WatchlistActor
+from _incydr_sdk.watchlists.models.responses import WatchlistMembersListV2
 from _incydr_sdk.watchlists.models.responses import WatchlistsPage
-from _incydr_sdk.watchlists.models.responses import WatchlistUser
 
 
 class WatchlistsClient:
     def __init__(self, parent):
         self._parent = parent
         self._v1 = None
+        self._v2 = None
 
     @property
     def v1(self):
@@ -35,25 +37,31 @@ class WatchlistsClient:
             self._v1 = WatchlistsV1(self._parent)
         return self._v1
 
+    @property
+    def v2(self):
+        if self._v2 is None:
+            self._v2 = WatchlistsV2(self._parent)
+        return self._v2
 
-class WatchlistsV1:
+
+class WatchlistsV2:
     """
-    Client for `/v1/watchlists` endpoints.
+    Client for `/v2/watchlists` endpoints.
 
     Usage example:
 
         >>> import incydr
         >>> client = incydr.Client(**kwargs)
-        >>> client.watchlists.v1.get_page()
+        >>> client.watchlists.v2.get_page()
     """
 
     def __init__(self, parent):
         self._parent = parent
         self._watchlist_type_id_map = {}
-        self._uri = "/v1/watchlists"
+        self._uri = "/v2/watchlists"
 
     def get_page(
-        self, page_num: int = 1, page_size: int = None, user_id: str = None
+        self, page_num: int = 1, page_size: int = None, actor_id: str = None
     ) -> WatchlistsPage:
         """
         Get a page of watchlists.
@@ -64,17 +72,19 @@ class WatchlistsV1:
 
         * **page_num**: `int` - Page number for results, starting at 1.
         * **page_size**: `int` - Max number of results to return for a page.
-        * **user_id**: `str` - Matches watchlists where the user is a member.
+        * **actor_id**: `str` - Matches watchlists where the actor is a member.
 
         **Returns**: A [`WatchlistsPage`][watchlistspage-model] object.
         """
         page_size = page_size or self._parent.settings.page_size
-        data = ListWatchlistsRequest(page=page_num, pageSize=page_size, userId=user_id)
+        data = ListWatchlistsRequestV2(
+            page=page_num, pageSize=page_size, actorId=actor_id
+        )
         response = self._parent.session.get(self._uri, params=data.dict())
         return WatchlistsPage.parse_response(response)
 
     def iter_all(
-        self, page_size: int = None, user_id: str = None
+        self, page_size: int = None, actor_id: str = None
     ) -> Iterator[Watchlist]:
         """
         Iterate over all watchlists.
@@ -86,7 +96,7 @@ class WatchlistsV1:
         page_size = page_size or self._parent.settings.page_size
         for page_num in count(1):
             page = self.get_page(
-                page_num=page_num, page_size=page_size, user_id=user_id
+                page_num=page_num, page_size=page_size, actor_id=actor_id
             )
             yield from page.watchlists
             if len(page.watchlists) < page_size:
@@ -169,172 +179,258 @@ class WatchlistsV1:
         )
         return Watchlist.parse_response(response)
 
-    def get_member(self, watchlist_id: str, user_id: str) -> WatchlistUser:
+    def get_member(self, watchlist_id: str, actor_id: str) -> WatchlistActor:
         """
-        Get a single member of a watchlist. A member may have been added as an included user, or is a member of an included department, etc.
+        Get a single member of a watchlist. A member may have been added as an included actor, or is a member of an included department, etc.
 
         **Parameters**:
 
          * **watchlist_id**: `str` (required) - Watchlist ID.
-        * **user_id**: `str` (required) - Unique user ID.
+        * **actor_id**: `str` (required) - Unique actor ID.
 
-        **Returns**: A [`WatchlistUser`][watchlistuser-model] object.
+        **Returns**: A [`WatchlistActor`][watchlistactor-model] object.
         """
         response = self._parent.session.get(
-            f"{self._uri}/{watchlist_id}/members/{user_id}"
+            f"{self._uri}/{watchlist_id}/members/{actor_id}"
         )
-        return WatchlistUser.parse_response(response)
+        return WatchlistActor.parse_response(response)
 
     def list_members(
-        self, watchlist_id: Union[str, WatchlistType]
-    ) -> WatchlistMembersList:
+        self,
+        watchlist_id: Union[str, WatchlistType],
+        page_num: int = None,
+        page_size: int = None,
+    ) -> WatchlistMembersListV2:
         """
-        Get a list of all members of a watchlist. These users may have been added as an included user, or are members of an included department, etc.
+        Get a list of all members of a watchlist. These actors may have been added as an included actor, or are members of an included department, etc.
 
         **Parameters**:
 
         * **watchlist_id**: `str`(required) - Watchlist ID.
+        * **page_num**: `int` (optional) - The page number to fetch, starting at 1.
+        * **page_size**: `int` (optional) - Max number of results to return for a page.
 
-        **Returns**: A [`WatchlistMembersList`][watchlistmemberslist-model] object.
+        **Returns**: A [`WatchlistMembersListV2`][watchlistmemberslistv2-model] object.
         """
-        response = self._parent.session.get(f"{self._uri}/{watchlist_id}/members")
-        return WatchlistMembersList.parse_response(response)
+        page_size = page_size or self._parent.settings.page_size
+        response = self._parent.session.get(
+            f"{self._uri}/{watchlist_id}/members",
+            params={"page": page_num, "page_size": page_size},
+        )
+        return WatchlistMembersListV2.parse_response(response)
 
-    def add_included_users(self, watchlist_id: str, user_ids: Union[str, List[str]]):
+    def iter_all_members(
+        self, watchlist_id: Union[str, WatchlistType], page_size: int = None
+    ) -> Iterator[WatchlistActor]:
         """
-        Include individual users on a watchlist.
+        Iterate over all members of a watchlist. These actors may have been added as an included actor, or are members of an included department, etc.
+
+        Accepts the same parameters as `.list_members()` excepting `page_num`.
+
+        **Returns**: A generator that yields [`WatchlistActor`][watchlistactor-model] objects.
+        """
+        page_size = page_size or self._parent.settings.page_size
+        for page_num in count(1):
+            page = self.list_members(
+                watchlist_id=watchlist_id, page_size=page_size, page_num=page_num
+            )
+            yield from page.watchlist_members
+            if len(page.watchlist_members) < page_size:
+                break
+
+    def add_included_actors(self, watchlist_id: str, actor_ids: Union[str, List[str]]):
+        """
+        Include individual actors on a watchlist.
 
         **Parameters**:
 
         * **watchlist**: `str` (required) - Watchlist ID.
-        * **user_ids**: `str`, `List[str]` (required) - List of unique user IDs to include on the watchlist.
+        * **actor_ids**: `str`, `List[str]` (required) - List of unique actor IDs to include on the watchlist. A maximum
+            of 100 actors can be processed in a single request.
 
         **Returns**: A `requests.Response` indicating success.
         """
-        data = UpdateIncludedUsersRequest(
-            userIds=user_ids if isinstance(user_ids, List) else [user_ids],
+        data = UpdateIncludedActorsRequest(
+            actorIds=actor_ids if isinstance(actor_ids, List) else [actor_ids],
             watchlistId=watchlist_id,
         )
         return self._parent.session.post(
-            url=f"{self._uri}/{watchlist_id}/included-users/add", json=data.dict()
+            url=f"{self._uri}/{watchlist_id}/included-actors/add", json=data.dict()
         )
 
-    def remove_included_users(self, watchlist_id: str, user_ids: Union[str, List[str]]):
+    def remove_included_actors(
+        self, watchlist_id: str, actor_ids: Union[str, List[str]]
+    ):
         """
-        Remove included users from a watchlist.
+        Remove included actors from a watchlist.
 
         **Parameters**:
 
         * **watchlist**: `str` (required) - Watchlist ID.
-        * **user_ids**: `str`, `List[str]` (required) - List of unique user IDs to remove from the watchlist.
+        * **actor_ids**: `str`, `List[str]` (required) - List of unique actor IDs to remove from the watchlist. A maximum
+            of 100 actors can be processed in a single request.
 
         **Returns**: A `requests.Response` indicating success.
         """
 
-        data = UpdateIncludedUsersRequest(
-            userIds=user_ids if isinstance(user_ids, List) else [user_ids],
+        data = UpdateIncludedActorsRequest(
+            actorIds=actor_ids if isinstance(actor_ids, List) else [actor_ids],
             watchlistId=watchlist_id,
         )
         return self._parent.session.post(
-            url=f"{self._uri}/{watchlist_id}/included-users/delete", json=data.dict()
+            url=f"{self._uri}/{watchlist_id}/included-actors/delete", json=data.dict()
         )
 
-    def get_included_user(self, watchlist_id: str, user_id: str) -> WatchlistUser:
+    def get_included_actor(self, watchlist_id: str, actor_id: str) -> WatchlistActor:
         """
-        Get an included user from a watchlist.
+        Get an included actor from a watchlist.
 
         **Parameters**:
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
-        * **user_id**: `str` (required) - Unique user ID.
+        * **actor_id**: `str` (required) - Unique actor ID.
 
-        **Returns**: A [`WatchlistUser`][watchlistuser-model] object.
+        **Returns**: A [`WatchlistActor`][watchlistactor-model] object.
         """
         response = self._parent.session.get(
-            url=f"{self._uri}/{watchlist_id}/included-users/{user_id}"
+            url=f"{self._uri}/{watchlist_id}/included-actors/{actor_id}"
         )
-        return WatchlistUser.parse_response(response)
+        return WatchlistActor.parse_response(response)
 
-    def list_included_users(self, watchlist_id: str) -> IncludedUsersList:
+    def list_included_actors(
+        self, watchlist_id: str, page_num: int = None, page_size: int = None
+    ) -> IncludedActorsList:
         """
-        List individual users included on a watchlist.
+        List individual actors included on a watchlist.
 
         **Parameters**:
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
+        * **page_num**: `int` (optional) - The page number to fetch, starting at 1.
+        * **page_size**: `int` (optional) - Max number of results to return for a page.
 
-        **Returns**: An [`IncludedUsersList`][includeduserslist-model] object.
+        **Returns**: An [`IncludedActorsList`][includedactorslist-model] object.
         """
-
+        page_size = page_size or self._parent.settings.page_size
         response = self._parent.session.get(
-            url=f"{self._uri}/{watchlist_id}/included-users"
+            url=f"{self._uri}/{watchlist_id}/included-actors",
+            params={"page": page_num, "page_size": page_size},
         )
-        return IncludedUsersList.parse_response(response)
+        return IncludedActorsList.parse_response(response)
 
-    def add_excluded_users(self, watchlist_id: str, user_ids: Union[str, List[str]]):
+    def iter_all_included_actors(
+        self, watchlist_id: str, page_size: int = None
+    ) -> Iterator[WatchlistActor]:
         """
-        Exclude individual users from a watchlist.
+        Iterate over all individual actors included on a watchlist.
+
+        Accepts the same parameters as `.list_included_actors()` excepting `page_num`.
+
+        **Returns**: A generator yielding individual [`WatchlistActor`][watchlistactor-model] objects.
+        """
+        page_size = page_size or self._parent.settings.page_size
+        for page_num in count(1):
+            page = self.list_included_actors(
+                watchlist_id=watchlist_id, page_num=page_num, page_size=page_size
+            )
+            yield from page.included_actors
+            if len(page.included_actors) < page_size:
+                break
+
+    def add_excluded_actors(self, watchlist_id: str, actor_ids: Union[str, List[str]]):
+        """
+        Exclude individual actors from a watchlist.
 
         **Parameters**:
 
         * **watchlist**: `str` (required) - Watchlist ID.
-        * **user_ids**: `str`, `List[str]` (required) - List of unique user IDs to exclude from the watchlist.
+        * **actor_ids**: `str`, `List[str]` (required) - List of unique actor IDs to exclude from the watchlist. A maximum
+            of 100 actors can be processed in a single request.
 
         **Returns**: A `requests.Response` indicating success.
         """
-        data = UpdateExcludedUsersRequest(
-            userIds=user_ids if isinstance(user_ids, List) else [user_ids],
+        data = UpdateExcludedActorsRequest(
+            actorIds=actor_ids if isinstance(actor_ids, List) else [actor_ids],
         )
         return self._parent.session.post(
-            url=f"{self._uri}/{watchlist_id}/excluded-users/add", json=data.dict()
+            url=f"{self._uri}/{watchlist_id}/excluded-actors/add", json=data.dict()
         )
 
-    def remove_excluded_users(self, watchlist_id: str, user_ids: Union[str, List[str]]):
+    def remove_excluded_actors(
+        self, watchlist_id: str, actor_ids: Union[str, List[str]]
+    ):
         """
-        Remove excluded users from a watchlist.
+        Remove excluded actors from a watchlist.
 
         **Parameters**:
 
         * **watchlist**: `str` (required) - Watchlist ID.
-        * **user_ids**: `str`, `List[str]` (required) - List of unique user IDs to remove from the exclusion list.
+        * **actor_ids**: `str`, `List[str]` (required) - List of unique actor IDs to remove from the exclusion list. A
+            maximum of 100 actors can be processed in a single request.
 
         **Returns**: A `requests.Response` indicating success.
         """
-        data = UpdateExcludedUsersRequest(
-            userIds=user_ids if isinstance(user_ids, List) else [user_ids],
+        data = UpdateExcludedActorsRequest(
+            actorIds=actor_ids if isinstance(actor_ids, List) else [actor_ids],
         )
         return self._parent.session.post(
-            url=f"{self._uri}/{watchlist_id}/excluded-users/delete", json=data.dict()
+            url=f"{self._uri}/{watchlist_id}/excluded-actors/delete", json=data.dict()
         )
 
-    def list_excluded_users(self, watchlist_id: str) -> ExcludedUsersList:
+    def list_excluded_actors(
+        self, watchlist_id: str, page_num: int = None, page_size: int = None
+    ) -> ExcludedActorsList:
         """
-        List individual users excluded from a watchlist.
+        List individual actors excluded from a watchlist.
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
+        * **page_num**: `int` (optional) - The page number to fetch, starting at 1.
+        * **page_size**: `int` (optional) - Max number of results to return for a page.
 
-        **Returns**: An [`ExcludedUsersList`][excludeduserslist-model] object.
+
+        **Returns**: An [`ExcludedActorsList`][excludedactorslist-model] object.
         """
+        page_size = page_size or self._parent.settings.page_size
         response = self._parent.session.get(
-            f"{self._uri}/{watchlist_id}/excluded-users"
+            f"{self._uri}/{watchlist_id}/excluded-actors",
+            params={"page": page_num, "page_size": page_size},
         )
-        return ExcludedUsersList.parse_response(response)
+        return ExcludedActorsList.parse_response(response)
 
-    def get_excluded_user(self, watchlist_id: str, user_id: str) -> WatchlistUser:
+    def iter_all_excluded_actors(
+        self, watchlist_id: str, page_size: int = None
+    ) -> Iterator[WatchlistActor]:
         """
-        Get an excluded user from a watchlist.
+        Iterate over all individual actors excluded from a watchlist.
+
+        Accepts the same parameters as `.list_excluded_actors()` excepting `page_num`.
+
+        **Returns**: A generator yielding individual [`WatchlistActor`][watchlistactor-model] objects.
+        """
+        page_size = page_size or self._parent.settings.page_size
+        for page_num in count(1):
+            page = self.list_excluded_actors(
+                page_num=page_num, page_size=page_size, watchlist_id=watchlist_id
+            )
+            yield from page.excluded_actors
+            if len(page.excluded_actors) < page_size:
+                break
+
+    def get_excluded_actor(self, watchlist_id: str, actor_id: str) -> WatchlistActor:
+        """
+        Get an excluded actor from a watchlist.
 
         **Parameters**:
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
-        * **user_id**: `str` (required) - Unique user ID.
+        * **actor_id**: `str` (required) - Unique actor ID.
 
-        **Returns**: A [`WatchlistUser`][watchlistuser-model] object.
+        **Returns**: A [`WatchlistActor`][watchlistactor-model] object.
         """
         response = self._parent.session.get(
-            f"{self._uri}/{watchlist_id}/excluded-users/{user_id}"
+            f"{self._uri}/{watchlist_id}/excluded-actors/{actor_id}"
         )
-        return WatchlistUser.parse_response(response)
+        return WatchlistActor.parse_response(response)
 
     def add_directory_groups(self, watchlist_id: str, group_ids: Union[str, List[str]]):
         """
@@ -376,22 +472,46 @@ class WatchlistsV1:
             json=data.dict(),
         )
 
-    def list_directory_groups(self, watchlist_id: str) -> IncludedDirectoryGroupsList:
+    def list_directory_groups(
+        self, watchlist_id: str, page_num: int = None, page_size: int = None
+    ) -> IncludedDirectoryGroupsList:
         """
         List directory groups included on a watchlist.
 
         **Parameters**:
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
+        * **page_num**: `int` (optional) - The page number to fetch, starting at 1.
+        * **page_size**: `int` (optional) - Max number of results to return for a page.
 
-        **Returns**: An [`IncludedUsersList`][includeduserslist-model] object.
+        **Returns**: An [`IncludedDirectoryGroupsList`][includeddirectorygroupslist-model] object.
         """
-
+        page_size = page_size or self._parent.settings.page_size
         response = self._parent.session.get(
-            f"{self._uri}/{watchlist_id}/included-directory-groups"
+            f"{self._uri}/{watchlist_id}/included-directory-groups",
+            params={"page": page_num, "page_size": page_size},
         )
         return IncludedDirectoryGroupsList.parse_response(response)
 
+    def iter_all_directory_groups(
+        self, watchlist_id: str, page_size: int = None
+    ) -> Iterator[IncludedDirectoryGroup]:
+        """
+        Iterate over all directory groups included on a watchlist.
+
+        Accepts the same parameters as `.list_directory_groups()` excepting `page_num`.
+
+        **Returns**: A generator yielding individual [`IncludedDirectoryGroup`][includeddirectorygroup-model] objects.
+        """
+        page_size = page_size or self._parent.settings.page_size
+        for page_num in count(1):
+            page = self.list_directory_groups(
+                page_num=page_num, page_size=page_size, watchlist_id=watchlist_id
+            )
+            yield from page.included_directory_groups
+            if len(page.included_directory_groups) < page_size:
+                break
+
     def get_directory_group(
         self, watchlist_id: str, group_id: str
     ) -> IncludedDirectoryGroup:
@@ -456,21 +576,46 @@ class WatchlistsV1:
             json=data.dict(),
         )
 
-    def list_departments(self, watchlist_id: str) -> IncludedDepartmentsList:
+    def list_departments(
+        self, watchlist_id: str, page_num: int = None, page_size: int = None
+    ) -> IncludedDepartmentsList:
         """
         List departments included on a watchlist.
 
         **Parameters**:
 
         * **watchlist_id**: `str` (required) - Watchlist ID.
+        * **page_num**: `int` - Page number for results, starting at 1.
+        * **page_size**: `int` - Max number of results to return for a page.
 
         **Returns**: An [`IncludedDepartmentsList`][includeddepartmentslist-model] object.
         """
         response = self._parent.session.get(
-            f"{self._uri}/{watchlist_id}/included-departments"
+            f"{self._uri}/{watchlist_id}/included-departments",
+            params={"page": page_num, "page_size": page_size},
         )
         return IncludedDepartmentsList.parse_response(response)
 
+    def iter_all_departments(
+        self, watchlist_id: str, page_size: int = None
+    ) -> Iterator[IncludedDepartment]:
+        """
+        Iterate over all departments included on a watchlist.
+
+        Accepts the same parameters as `.list_departments()` excepting `page_num`.
+
+        **Returns**: A generator yielding individual [`IncludedDepartment`][includeddepartment-model] objects.
+
+        """
+        page_size = page_size or self._parent.settings.page_size
+        for page_num in count(1):
+            page = self.list_departments(
+                page_num=page_num, page_size=page_size, watchlist_id=watchlist_id
+            )
+            yield from page.included_departments
+            if len(page.included_departments) < page_size:
+                break
+
     def get_department(self, watchlist_id: str, department: str) -> IncludedDepartment:
         """
         Get an included department from a watchlist.
