@@ -1,3 +1,8 @@
+from _incydr_sdk.actors.models import Actor
+from _incydr_sdk.actors.models import ActorFamily
+from _incydr_sdk.actors.models import ActorsPage
+from _incydr_sdk.agents.models import Agent
+from _incydr_sdk.agents.models import AgentsPage
 from _incydr_sdk.alert_rules.models.response import RuleDetails
 from _incydr_sdk.alert_rules.models.response import RuleUser
 from _incydr_sdk.alert_rules.models.response import RuleUsersList
@@ -18,26 +23,38 @@ from _incydr_sdk.file_events.models.event import FileEventV2
 from _incydr_sdk.file_events.models.event import User
 from _incydr_sdk.file_events.models.response import FileEventsPage
 from _incydr_sdk.file_events.models.response import SavedSearch
+from _incydr_sdk.risk_profiles.models import RiskProfile
+from _incydr_sdk.risk_profiles.models import RiskProfilesPage
+from _incydr_sdk.sessions.models.response import Session
+from _incydr_sdk.sessions.models.response import SessionsPage
 from _incydr_sdk.trusted_activities.models import TrustedActivitiesPage
 from _incydr_sdk.trusted_activities.models import TrustedActivity
-from _incydr_sdk.user_risk_profiles.models import UserRiskProfile
-from _incydr_sdk.user_risk_profiles.models import UserRiskProfilesPage
 from _incydr_sdk.users.models import Role
 from _incydr_sdk.users.models import UpdateRolesResponse
 from _incydr_sdk.users.models import UserRole
 from _incydr_sdk.users.models import UsersPage
+from _incydr_sdk.watchlists.models.responses import ExcludedActorsList
 from _incydr_sdk.watchlists.models.responses import ExcludedUsersList
+from _incydr_sdk.watchlists.models.responses import IncludedActorsList
 from _incydr_sdk.watchlists.models.responses import IncludedDepartment
 from _incydr_sdk.watchlists.models.responses import IncludedDepartmentsList
 from _incydr_sdk.watchlists.models.responses import IncludedDirectoryGroup
 from _incydr_sdk.watchlists.models.responses import IncludedDirectoryGroupsList
 from _incydr_sdk.watchlists.models.responses import IncludedUsersList
 from _incydr_sdk.watchlists.models.responses import Watchlist
+from _incydr_sdk.watchlists.models.responses import WatchlistActor
 from _incydr_sdk.watchlists.models.responses import WatchlistMembersList
+from _incydr_sdk.watchlists.models.responses import WatchlistMembersListV2
 from _incydr_sdk.watchlists.models.responses import WatchlistsPage
 from _incydr_sdk.watchlists.models.responses import WatchlistUser
 
+
 __all__ = [
+    "Actor",
+    "ActorFamily",
+    "ActorsPage",
+    "Agent",
+    "AgentsPage",
     "AlertDetails",
     "AlertSummary",
     "AlertQueryPage",
@@ -58,6 +75,8 @@ __all__ = [
     "RuleUsersList",
     "RuleUser",
     "RuleDetails",
+    "Session",
+    "SessionsPage",
     "TrustedActivity",
     "TrustedActivitiesPage",
     "DepartmentsPage",
@@ -65,17 +84,21 @@ __all__ = [
     "DirectoryGroup",
     "Watchlist",
     "WatchlistsPage",
+    "WatchlistMembersListV2",
     "WatchlistMembersList",
+    "IncludedActorsList",
+    "ExcludedActorsList",
     "ExcludedUsersList",
     "IncludedUsersList",
+    "WatchlistActor",
     "WatchlistUser",
     "IncludedDepartmentsList",
     "IncludedDepartment",
     "IncludedDirectoryGroupsList",
     "IncludedDirectoryGroup",
     "AuditEventsPage",
-    "UserRiskProfilesPage",
-    "UserRiskProfile",
+    "RiskProfilesPage",
+    "RiskProfile",
 ]
 
 
